@@ -523,6 +523,9 @@ class Resource(object):
             return False
         return self._info == other._info
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def is_loaded(self):
         return self._loaded
 
