@@ -1,8 +1,5 @@
 # Copyright Ericsson AB 2014. All rights reserved
 #
-# Authors: Balazs Gibizer <balazs.gibizer@ericsson.com>
-#          Ildiko Vancsa <ildiko.vancsa@ericsson.com>
-#
 #   Licensed under the Apache License, Version 2.0 (the "License"); you may
 #   not use this file except in compliance with the License. You may obtain
 #   a copy of the License at
@@ -38,7 +35,7 @@ from ceilometerclient.v2 import shell as ceilometer_shell
 from ceilometerclient.v2 import statistics
 from ceilometerclient.v2 import trait_descriptions
 from ceilometerclient.v2 import traits
-from keystoneclient import exceptions
+from keystoneauth1 import exceptions
 
 
 class ShellAlarmStateCommandsTest(utils.BaseTestCase):
@@ -266,6 +263,18 @@ class ShellAlarmCommandTest(utils.BaseTestCase):
         method = ceilometer_shell.do_alarm_threshold_update
         self._do_test_alarm_update_repeat_actions(method, False)
 
+    def test_alarm_event_upadte_repeat_action_untouched(self):
+        method = ceilometer_shell.do_alarm_event_update
+        self._do_test_alarm_update_repeat_actions(method, None)
+
+    def test_alarm_event_upadte_repeat_action_set(self):
+        method = ceilometer_shell.do_alarm_event_update
+        self._do_test_alarm_update_repeat_actions(method, True)
+
+    def test_alarm_event_upadte_repeat_action_clear(self):
+        method = ceilometer_shell.do_alarm_event_update
+        self._do_test_alarm_update_repeat_actions(method, False)
+
     @mock.patch('sys.stdout', new=six.StringIO())
     def test_alarm_threshold_create_args(self):
         argv = ['alarm-threshold-create'] + self.THRESHOLD_ALARM_CLI_ARGS
@@ -529,72 +538,11 @@ class ShellAlarmGnocchiCommandTest(test_shell.ShellTestBase):
         ceilometer_shell.\
             do_alarm_gnocchi_aggregation_by_metrics_threshold_create(
                 self.cc, self.args)
-        self.assertEqual('''\
-+---------------------------+------------------------------------------\
---------------------------+
-| Property                  | Value                                    \
-                          |
-+---------------------------+------------------------------------------\
---------------------------+
-| aggregation_method        | count                                    \
-                          |
-| alarm_actions             | ["http://something/alarm"]               \
-                          |
-| alarm_id                  | b69ecdb9-f19b-4fb5-950f-5eb53938b718     \
-                          |
-| comparison_operator       | le                                       \
-                          |
-| description               | description_gnocchi_alarm                \
-                          |
-| enabled                   | True                                     \
-                          |
-| evaluation_periods        | 3                                        \
-                          |
-| granularity               | 60                                       \
-                          |
-| insufficient_data_actions | ["http://something/insufficient"]        \
-                          |
-| metrics                   | ["b3d9d8ab-05e8-439f-89ad-5e978dd2a5eb", \
-"009d4faf-c275-46f0-8f2d- |
-|                           | 670b15bac2b0"]                           \
-                          |
-| name                      | name_gnocchi_alarm                       \
-                          |
-| ok_actions                | ["http://something/ok"]                  \
-                          |
-| project_id                | 97fcad0402ce4f65ac3bd42a0c6a7e74         \
-                          |
-| repeat_actions            | True                                     \
-                          |
-| severity                  | critical                                 \
-                          |
-| state                     | ok                                       \
-                          |
-| threshold                 | 70.0                                     \
-                          |
-| time_constraints          | [{name: cons1,                           \
-                          |
-|                           |   description: desc1,                    \
-                          |
-|                           |   start: 0 11 * * *,                     \
-                          |
-|                           |   duration: 300},                        \
-                          |
-|                           |  {name: cons2,                           \
-                          |
-|                           |   description: desc2,                    \
-                          |
-|                           |   start: 0 23 * * *,                     \
-                          |
-|                           |   duration: 600}]                        \
-                          |
-| type                      | gnocchi_aggregation_by_metrics_threshold \
-                          |
-| user_id                   | f28735621ee84f329144eb467c91fce6         \
-                          |
-+---------------------------+------------------------------------------\
---------------------------+
-''', sys.stdout.getvalue())
+        stdout = sys.stdout.getvalue()
+        self.assertIn("b69ecdb9-f19b-4fb5-950f-5eb53938b718", stdout)
+        self.assertIn("[\"http://something/alarm\"]", stdout)
+        self.assertIn("description_gnocchi_alarm", stdout)
+        self.assertIn("gnocchi_aggregation_by_metrics_threshold", stdout)
 
     @mock.patch('sys.stdout', new=six.StringIO())
     def test_do_alarm_gnocchi_aggr_by_resources_threshold_create(self):
